@@ -274,6 +274,11 @@ class ShelfPageView(ShelfModelView):
     can_delete = False
 
     edit_template = "shelf-admin/page/edit.html"
+
+    pages_form = {}
+
+    def register_form(self, cls, form):
+        self.pages_form[cls] = form
     
     def edit_form(self, obj=None):
         """
@@ -281,6 +286,12 @@ class ShelfPageView(ShelfModelView):
 
             Override to implement custom behavior.
         """
+        if not obj:
+            raise ValueError
+
+        if obj.__class__ in self.pages_form:
+            return self.pages_form[obj.__class__]()
+
         converter = self.model_form_converter(self.session, self)
         cls = contribform.get_form(obj.__class__, converter,
                                    base_class=self.form_base_class,
